@@ -2,7 +2,7 @@ package HTTP::MobileAgent::AirHPhone;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = 0.09;
+$VERSION = q(0.10);
 
 use base qw(HTTP::MobileAgent);
 
@@ -22,6 +22,11 @@ sub parse {
     $self->{cache_size} =~ s/^c//;
 }
 
+sub _make_display {
+    # XXX
+}
+
+
 1;
 __END__
 
